@@ -272,10 +272,14 @@ class TestGlmPoissonFwClu(CheckWeight):
         # no wnobs yet in sandwich covariance calcualtion
         cls.corr_fact = 1 / np.sqrt(n_groups / (n_groups - 1))   #np.sqrt((wsum - 1.) / wsum)
         cov_kwds = {'groups': gid, 'use_correction':False}
-        with pytest.warns(None):
-            mod = GLM(cpunish_data.endog, cpunish_data.exog,
-                      family=sm.families.Poisson(),
-                      freq_weights=fweights)
+
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+
+            mod = GLM(
+                cpunish_data.endog, cpunish_data.exog,
+                family=sm.families.Poisson(), freq_weights=fweights
+            )
             cls.res1 = mod.fit(cov_type='cluster', cov_kwds=cov_kwds)
 
         # compare with discrete, start close to save time
@@ -571,9 +575,9 @@ def test_wtd_gradient_irls():
                                     atol=5e-5)
 
 
-def get_dummies(x):
+def get_dummies(x, dtype=float):
     values = np.sort(np.unique(x))
-    out = np.zeros(shape=(x.shape[0], len(values) - 1))
+    out = np.zeros(shape=(x.shape[0], len(values) - 1), dtype=dtype)
     for i, v in enumerate(values):
         if i == 0:
             continue
@@ -591,7 +595,7 @@ class TestRepeatedvsAggregated(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x)
+        exog[:, 2:] = get_dummies(x, dtype=float)
         beta = np.array([-1, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Poisson
@@ -622,7 +626,7 @@ class TestRepeatedvsAverage(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x)
+        exog[:, 2:] = get_dummies(x, dtype=float)
         beta = np.array([-1, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Poisson
@@ -653,7 +657,7 @@ class TestTweedieRepeatedvsAggregated(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x)
+        exog[:, 2:] = get_dummies(x, dtype=float)
         beta = np.array([7, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Tweedie
@@ -685,7 +689,7 @@ class TestTweedieRepeatedvsAverage(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x)
+        exog[:, 2:] = get_dummies(x, dtype=float)
         beta = np.array([7, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Tweedie
@@ -718,7 +722,7 @@ class TestBinomial0RepeatedvsAverage(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x)
+        exog[:, 2:] = get_dummies(x, dtype=float)
         beta = np.array([-1, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Binomial
@@ -751,7 +755,7 @@ class TestBinomial0RepeatedvsDuplicated(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x)
+        exog[:, 2:] = get_dummies(x, dtype=float)
         beta = np.array([-1, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Binomial
