@@ -1,5 +1,5 @@
 """Module for functional boxplots."""
-from statsmodels.compat.numpy import NP_LT_123
+from statsmodels.compat.numpy import NP_LT_122
 
 import numpy as np
 from scipy.special import comb
@@ -22,7 +22,7 @@ from . import utils
 __all__ = ['hdrboxplot', 'fboxplot', 'rainbowplot', 'banddepth']
 
 
-class HdrResults(object):
+class HdrResults:
     """Wrap results and pretty print them."""
 
     def __init__(self, kwds):
@@ -330,7 +330,7 @@ def hdrboxplot(data, ncomp=2, alpha=None, threshold=0.95, bw=None,
 
     n_quantiles = len(alpha)
     pdf_r = ks_gaussian.pdf(data_r).flatten()
-    if NP_LT_123:
+    if NP_LT_122:
         pvalues = [np.percentile(pdf_r, (1 - alpha[i]) * 100,
                                  interpolation='linear')
                    for i in range(n_quantiles)]
