@@ -169,7 +169,7 @@ def load_basic_cohn():
 
 
 class Test__ros_sort(object):
-    def setup(self):
+    def setup_method(self):
         self.df = load_basic_data()
 
         self.expected_baseline = pandas.DataFrame([
@@ -208,7 +208,7 @@ class Test__ros_sort(object):
 
 
 class Test_cohn_numbers(object):
-    def setup(self):
+    def setup_method(self):
         self.df = load_basic_data()
         self.final_cols = ['lower_dl', 'upper_dl', 'nuncen_above', 'nobs_below',
                            'ncen_equal', 'prob_exceedance']
@@ -243,7 +243,7 @@ class Test_cohn_numbers(object):
 
 
 class Test__detection_limit_index(object):
-    def setup(self):
+    def setup_method(self):
         self.cohn = load_basic_cohn()
         self.empty_cohn = pandas.DataFrame(numpy.empty((0, 7)))
 
@@ -273,7 +273,7 @@ def test__ros_group_rank():
 
 
 class Test__ros_plot_pos(object):
-    def setup(self):
+    def setup_method(self):
         self.cohn = load_basic_cohn()
 
     def test_uncensored_1(self):
