@@ -1,5 +1,6 @@
 from statsmodels.compat.pandas import Appender, is_numeric_dtype
 from statsmodels.compat.python import lmap, lrange
+from statsmodels.compat.scipy import SP_LT_19
 
 from typing import Sequence, Union
 import warnings
@@ -158,7 +159,11 @@ def sign_test(samp, mu0=0):
     pos = np.sum(samp > mu0)
     neg = np.sum(samp < mu0)
     M = (pos - neg) / 2.0
-    p = stats.binom_test(min(pos, neg), pos + neg, 0.5)
+    try:
+        p = stats.binomtest(min(pos, neg), pos + neg, 0.5).pvalue
+    except AttributeError:
+        # Remove after min SciPy >= 1.7
+        p = stats.binom_test(min(pos, neg), pos + neg, 0.5)
     return M, p
 
 
@@ -315,7 +320,7 @@ class Description:
         if self._data.shape[1] == 0:
 
             raise ValueError(
-                "Selecting {col_types} results in an empty DataFrame"
+                f"Selecting {col_types} results in an empty DataFrame"
             )
         self._is_numeric = [is_numeric_dtype(dt) for dt in self._data.dtypes]
         self._is_cat_like = [
@@ -408,14 +413,20 @@ class Description:
         mean = df.mean()
         mad = (df - mean).abs().mean()
         std_err = std.copy()
-        std_err.loc[count > 0] /= count.loc[count > 0]
+        std_err.loc[count > 0] /= count.loc[count > 0] ** 0.5
         if self._use_t:
             q = stats.t(count - 1).ppf(1.0 - self._alpha / 2)
         else:
             q = stats.norm.ppf(1.0 - self._alpha / 2)
 
         def _mode(ser):
-            mode_res = stats.mode(ser.dropna())
+            if SP_LT_19:
+                mode_res = stats.mode(ser.dropna())
+            else:
+                mode_res = stats.mode(ser.dropna(), keepdims=True)
+            # Changes in SciPy 1.10
+            if np.isscalar(mode_res[0]):
+                return float(mode_res[0]), mode_res[1]
             if mode_res[0].shape[0] > 0:
                 return [float(val) for val in mode_res]
             return np.nan, np.nan
@@ -738,10 +749,16 @@ class Describe(object):
         return p
 
     def _mode_val(self, x):
-        return stats.mode(x)[0][0]
+        try:
+            return stats.mode(x, keepdims=True)[0][0]
+        except TypeError:
+            return stats.mode(x)[0][0]
 
     def _mode_bin(self, x):
-        return stats.mode(x)[1][0]
+        try:
+            return stats.mode(x, keepdims=True)[1][0]
+        except TypeError:
+            return stats.mode(x)[1][0]
 
     def _array_typer(self):
         """if not a sctructured array"""
