@@ -230,7 +230,7 @@ class TestTrivariateConventionalAlternate(TestTrivariateConventional):
             alternate_timing=True, *args, **kwargs)
 
     def test_using_alterate(self):
-        assert(self.model._kalman_filter.filter_timing == 1)
+        assert self.model._kalman_filter.filter_timing == 1
 
 
 class TestTrivariateConventionalPartialMissing(Trivariate):
@@ -271,7 +271,7 @@ class TestTrivariateConventionalPartialMissingAlternate(
               cls).setup_class(alternate_timing=True, *args, **kwargs)
 
     def test_using_alterate(self):
-        assert(self.model._kalman_filter.filter_timing == 1)
+        assert self.model._kalman_filter.filter_timing == 1
 
 
 class TestTrivariateConventionalAllMissing(Trivariate):
@@ -312,7 +312,7 @@ class TestTrivariateConventionalAllMissingAlternate(
             alternate_timing=True, *args, **kwargs)
 
     def test_using_alterate(self):
-        assert(self.model._kalman_filter.filter_timing == 1)
+        assert self.model._kalman_filter.filter_timing == 1
 
 
 class TestTrivariateUnivariate(Trivariate):
@@ -348,7 +348,7 @@ class TestTrivariateUnivariateAlternate(TestTrivariateUnivariate):
             alternate_timing=True, *args, **kwargs)
 
     def test_using_alterate(self):
-        assert(self.model._kalman_filter.filter_timing == 1)
+        assert self.model._kalman_filter.filter_timing == 1
 
 
 class TestTrivariateUnivariatePartialMissing(Trivariate):
@@ -389,7 +389,7 @@ class TestTrivariateUnivariatePartialMissingAlternate(
               cls).setup_class(alternate_timing=True, *args, **kwargs)
 
     def test_using_alterate(self):
-        assert(self.model._kalman_filter.filter_timing == 1)
+        assert self.model._kalman_filter.filter_timing == 1
 
 
 class TestTrivariateUnivariateAllMissing(Trivariate):
@@ -430,7 +430,7 @@ class TestTrivariateUnivariateAllMissingAlternate(
             alternate_timing=True, *args, **kwargs)
 
     def test_using_alterate(self):
-        assert(self.model._kalman_filter.filter_timing == 1)
+        assert self.model._kalman_filter.filter_timing == 1
 
 
 class TestDFM(object):
